==> owncloud-app-contacts-2%3A1.3.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/sq.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakte",
    "Address book name" : "Emër libri adresash",
    "Import" : "Importoje",
    "No contacts in here" : "S’ka kontakte këtu",
    "Name" : "Emër",
    "Organization" : "Organizëm",
    "Title" : "Titull",
    "Add field ..." : "Shtoni fushë...",
    "Add contact" : "Shtoni kontakt",
    "No search result for {query}" : "S’pat përfundime kërkimi për {query}",
    "All contacts" : "Krejt kontaktet",
    "Not grouped" : "I pagrupuar",
    "Post Office Box" : "Kuti Zyre Postare",
    "Postal Code" : "Kod Postar",
    "City" : "Qytet",
    "State or province" : "Shtet ose provincë",
    "Country" : "Vend",
    "Address" : "Adresë",
    "(new group)" : "(grup i ri)",
    "New contact" : "Kontakt i ri",
    "{addressbook} shared by {owner}" : "{addressbook} ndarë nga {owner}",
    "No contacts in file. Only VCard files are allowed." : "S’ka kontakte në kartelë. Lejohen vetëm kartela VCard.",
    "Nickname" : "Nofkë",
    "Notes" : "Shënime",
    "Website" : "Sajt",
    "Federated Cloud ID" : "ID Federated Cloud",
    "Home" : "Kreu",
    "Work" : "Pune",
    "Other" : "Tjetër",
    "Groups" : "Grupe",
    "Birthday" : "Datëlindje",
    "Email" : "Email",
    "Instant messaging" : "Shkëmbim i atypëratyshëm mesazhesh",
    "Phone" : "Telefon",
    "Mobile" : "Celular",
    "Fax" : "Faks",
    "Fax home" : "Faks shtëpie",
    "Fax work" : "Faks pune",
    "Pager" : "Faques",
    "Voice" : "Zë",
    "Social Network" : "Rrjet Shoqëror",
    "Settings" : "Rregullime"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/sq.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakte",
    "Address book name" : "Emër libri adresash",
    "Import" : "Importoje",
    "The selected image is too big (max 1MB)" : "Figura e përzgjedhur është shumë e madhe (maksimumi 1MB)",
    "No contacts in here" : "S’ka kontakte këtu",
    "Name" : "Emër",
    "Organization" : "Organizëm",
    "Title" : "Titull",
    "Add field ..." : "Shtoni fushë...",
    "+ New contact" : "+ Kontakt i ri",
    "No search result for {query}" : "S’pat përfundime kërkimi për {query}",
    "_%n contact_::_%n contacts_" : ["%n kontakt","%n kontakte"],
    "Post office box" : "Kuti postare në postë",
    "Postal code" : "Kod postar",
    "City" : "Qytet",
    "State or province" : "Shtet ose provincë",
    "Country" : "Vend",
    "Address" : "Adresë",
    "(new group)" : "(grup i ri)",
    "Last name" : "Mbiemër",
    "First name" : "Emër",
    "Additional names" : "Emra shtesë",
    "Prefix" : "Parashtesë",
    "Suffix" : "Prapashtesë",
    "All contacts" : "Krejt kontaktet",
    "Not grouped" : "I pagrupuar",
    "New contact" : "Kontakt i ri",
    "{addressbook} shared by {owner}" : "{addressbook} ndarë nga {owner}",
    "No contacts in file. Only VCard files are allowed." : "S’ka kontakte në kartelë. Lejohen vetëm kartela VCard.",
    "Nickname" : "Nofkë",
    "Detailed name" : "Emri i hollësishëm",
    "Notes" : "Shënime",
    "Website" : "Sajt",
    "Federated Cloud ID" : "ID Federated Cloud",
    "Home" : "Kreu",
    "Work" : "Pune",
    "Other" : "Tjetër",
    "Groups" : "Grupe",
    "Birthday" : "Datëlindje",
    "Anniversary" : "Përvjetor",
    "Date of death" : "Datë vdekjeje",
    "Email" : "Email",
    "Instant messaging" : "Shkëmbim i atypëratyshëm mesazhesh",
    "Phone" : "Telefon",
    "Mobile" : "Celular",
    "Fax" : "Faks",
    "Fax home" : "Faks shtëpie",
    "Fax work" : "Faks pune",
    "Pager" : "Faques",
    "Voice" : "Zë",
    "Social network" : "Rrjet shoqëror",
    "Settings" : "Rregullime"
},
"nplurals=2; plural=(n != 1);");
